FlutterWindClassHandler class
Constructors
- FlutterWindClassHandler({required String name, required FlutterWindClassApply apply, int order = 0})
-
const
Properties
- apply → FlutterWindClassApply
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- order → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited